# @Time : 2020/7/21 10:49 
# @Author : XX
# @File : one.py 
# @Software: PyCharm

import os
import pandas as pd
import numpy as np
from sklearn.preprocessing import StandardScaler
from keras.layers import Conv2D,MaxPool2D,Dense,Flatten
from keras.utils import np_utils
from keras.models import Sequential
from sklearn.model_selection import train_test_split
model = Sequential()
# 1. 两个卷积层，一个池化层
#     卷积层：64个卷积核
model.add(Conv2D(filters=64,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=64,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 2. 两个卷积一个池化
#     卷积层：128个卷积核
model.add(Conv2D(filters=128,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=128,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 3. 三个卷积一个池化
#     卷积：256个卷积核
model.add(Conv2D(filters=256,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=256,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=256,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 4. 三个卷积一个池化
#     卷积：512个卷积核
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 5. 三个卷积一个池化
#     卷积：512个卷积核
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 6. 全连接层：
#     1. 神经元：4096个，Relu
model.add(Flatten())
model.add(Dense(units=4096,activation='relu'))
#     2. 神经元：4096个，Relu
model.add(Dense(units=4096,activation='relu'))
#     3. 神经元：1000个，SoftMax
model.add(Dense(units=5,activation='softmax'))
model.compile(optimizer='adam',loss='categorical_crossentropy',metrics=['accuracy'])
model.fit(datas,Y,epochs=200)




































"""1.Query 纠错"""
"""1.Query 纠错，顾名思义，也即对用户输入 query 出现的错误进行检测和纠正的过程。用户在使用搜索过程中，
可能由于先验知识掌握不够或输入过程引入噪音 ( 如：语音识别有误、快速输入手误等 ) 输入的搜索 query 会存在一定的错误。
如果不对带有错误的 query 进行纠错，除了会影响 QU 其他模块的准确率，还会影响召回的相关性及排序的合理性，
最终影响到用户的搜索体验。
除了搜索场景，query 纠错还可以应用于输入法、人机对话、语音识别、内容审核等应用场景。不同的业务场景需要解决的错误类型会不太一样，
比如 ASR 语音识别主要解决同谐音、模糊音等错误，而输入法及搜索等场景则需要面临解决几乎所有错误类型，如同谐音、模糊音 ( 平舌翘舌、前后鼻音等 )、
混淆音、形近字 ( 主要针对五笔和笔画手写输入法 )、多漏字等错误。根据 query 中是否有不在词典中本身就有错误的词语 ( Non-word )，可以将 query 错
误类型主要分为 Non-word 和 Real-word 两类错误。
其中，Non-word 错误一般出现在带英文单词或数字的 query 中，由于通过输入法进行输入，不会存在错误中文字的情况，所以中文 query 如果以字作为最小语
义单元的话一般只会存在 Real-word 错误，而带英文数字的 query 则可能存在两类错误。"""


"""请简述意图识别的难点(三个即可)"""
"""2.用户输入 query 不规范：由于用户先验知识的差异，必然导致用户在通过自然语言组织表达同一需求时千差万别，
甚至可能会出现 query 表达错误、遗漏等情况；

歧义性&多样性：用户的搜索 query 表达不够明确带来的意图歧义性或用户本身搜索意图存在多样性，
比如：搜索 query "择天记"可能是想下载仙侠玄幻类游戏，可能是玄幻小说类 app，也可能是想看择天记电视剧而下视频类 app。
此时衍生出来的另一个问题是当某个 query 存在多个意图可能时，需要合理地量化各个意图的需求强度；

如何根据用户及其所处 context 的不同实现个性化意图，比如用户的性别、年龄不同，搜索同一 query 的意图可能不一样，
用户当前时刻搜索 query 的意图可能和上一时刻搜索 query 相关等。"""


"""1.为什么LSTM模型中既存在sigmoid又存在tanh两种激活函数，而不是选择统一一种sigmoid或者tanh？这样做的目的是什么？"""
"""sigmoid 用在了各种gate上，产生0~1之间的值，这个一般只有sigmoid最直接了。
tanh 用在了状态和输出上，是对数据的处理，这个用其他激活函数或许也可以。"""



"""什麽样的资料集不适合用深度学习？"""
"""（1）数据集太小，数据样本不足时，深度学习相对其它机器学习算法，没有明显优势。
（2）数据集没有局部相关特性，目前深度学习表现比较好的领域主要是图像／语音／自然语言处理等领域，
这些领域的一个共性是局部相关性。图像中像素组成物体，语音信号中音位组合成单词，文本数据中单词组合成句子，
这些特征元素的组合一旦被打乱，表示的含义同时也被改变。对于没有这样的局部相关性的数据集，不适于使用深度学习算法进行处理。
举个例子：预测一个人的健康状况，相关的参数会有年龄、职业、收入、家庭状况等各种元素，将这些元素打乱，并不会影响相关的结果。"""


"""1.GRU是什么？GRU对LSTM做了哪些改动？"""
"""GRU是Gated Recurrent Units，是循环神经网络的一种。
GRU只有两个门（update和reset），LSTM有三个门（forget，input，output），GRU直接将hidden state 传给下一个单元，而LSTM用memory cell 把hidden state 包装起来。"""


"""缓解过拟合：
① Dropout
② 加L1/L2正则化
③ BatchNormalization
④ 网络bagging"""


# @Time : 2020/7/21 9:56 
# @Author : XX
# @File : two.py 
# @Software: PyCharm

import pandas as pd
import matplotlib.pyplot as plt
from sklearn.ensemble import RandomForestRegressor
from sklearn.preprocessing import MinMaxScaler# 最小值最大值归一化
from sklearn.model_selection import train_test_split # 训练测试分割
from sklearn.neighbors import KNeighborsClassifier,KNeighborsRegressor

df = pd.read_csv(r'G:\Desktop\科委资格认证\新建文件夹\考试题\数据挖掘\数据集\creditcard.csv')
# 拆分为特征矩阵和目标向量
X = df.iloc[:,:-1]
Y = df.iloc[:,-1]
# 归一
s = MinMaxScaler()
s.fit(X)
X = s.transform(X)
# 分割训练集和测试集
train_x,test_x,train_y,test_y=train_test_split(X,Y,test_size=0.1)


# 显示出随机森林特征的重要性，并做条形图
rfr = RandomForestRegressor(min_samples_split=6, n_estimators=100)
rfr.fit(train_x, train_y)
print(rfr.score(test_x, test_y))
# 使用pd.Series进行组合，值是特征重要性的值，index是样本特征，.sort_value 进行排序操作
feature_important = pd.Series(rfr.feature_importances_, index = df.V1).sort_values(ascending=False)
plt.bar(feature_important.index, feature_important.data)
plt.show()


# @Time : 2020/7/21 10:05 
# @Author : XX
# @File : one.py 
# @Software: PyCharm

#!/usr/bin/env python
# coding:utf-8

import requests
from hashlib import md5

class Chaojiying_Client(object):

    def __init__(self, username, password, soft_id):
        self.username = username
        password =  password.encode('utf8')
        self.password = md5(password).hexdigest()
        self.soft_id = soft_id
        self.base_params = {
            'user': self.username,
            'pass2': self.password,
            'softid': self.soft_id,
        }
        self.headers = {
            'Connection': 'Keep-Alive',
            'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)',
        }

    def PostPic(self, im, codetype):
        """
        im: 图片字节
        codetype: 题目类型 参考 http://www.chaojiying.com/price.html
        """
        params = {
            'codetype': codetype,
        }
        params.update(self.base_params)
        files = {'userfile': ('ccc.jpg', im)}
        r = requests.post('http://upload.chaojiying.net/Upload/Processing.php', data=params, files=files, headers=self.headers)
        return r.json()

    def ReportError(self, im_id):
        """
        im_id:报错题目的图片ID
        """
        params = {
            'id': im_id,
        }
        params.update(self.base_params)
        r = requests.post('http://upload.chaojiying.net/Upload/ReportError.php', data=params, headers=self.headers)
        return r.json()


def getcode(im):
    chaojiying = Chaojiying_Client()
    return chaojiying.PostPic(im, 1902)['pic_str']































































































"""
1、目标达成率，完成百分比，提升百分比
2、核心数据走势图
3、流量分析
4、转化率分析
5、模块点击分析
6、改进及优化
（答案不唯一）
"""

"""
1.日常运营报告
日常运营报告通常是指新媒体运营部门每天、每周或每月、每季度需要给主管领导进行汇报，
这其中包括《网站流量日报》、《微信公众号粉丝周报》以及《今日头条阅读量周报、粉丝月报》还有《网站转化率月报》等
2.专项研究报告
专项研究报告主要是指针对某个特定问题进行的相关数据汇总和分析，比如《粉丝增长来源报告》、
《流量异常分析报告》、《上周广告投放效果报告》等，专项研究报告的重点是深入挖掘问题，以及寻找解决问题方案。
这些报告是针对特别事件孕育而生的产物，所以是不定期报告
3.行业分析报告
行业分析报告是对整个新媒体行业的情况汇总报告，主要是分析当前新媒体的相关情况，
这样可以有助于掌握整个趋势，比如抖音风刚起，就能判断短视频平台即将到来的大佬们都获得了最高的流量支持。
行业分析报告主要分两点，一是整个行业的报告，一是同行竞争对手的报告，整个行业趋势可以通过大数据来获得相关数据，
而同行分析，则是通过分析竞争对手的微博数据、微信数据来了解他们的大概情况。
"""

"""
1.PCA 的思想是将 n 维特征映射到 k 维上（k<n），这 k 维是全新的正交特征。
这 k 维特征称为主成分，是重新构造出来的 k 维特征，而不是简单地从 n 维特征中去除其余 n-k 维特征。
PCA 的目的是选择更少的主成分（与特征变量个数相较而言），那些选上的主成分能够解释数据集中最大方差。
通过正交变换，各主成分的相对位置不发生变化，它只能改变点的实际坐标。  
"""

"""
解决不平衡分类问题的策略可以分为两大类：一类是从训练集入手 ,
 通过改变训练集样本分布，降低不平衡程度；另一类是从学习算法入手 , 
 根据算法在解决不平衡问题时的缺陷 , 适当地修改算法使之适应不平衡分类问题。
 平衡训练集的方法主要有训练集重采样 (re-sampling)方法和训练集划分方法。
 学习算法层面的策略包括分类器集成 、代价敏感学习和特征选择方法等。
"""




# @Time : 2020/7/21 10:03 
# @Author : XX
# @File : five.py 
# @Software: PyCharm

from sklearn.ensemble import BaggingClassifier
from sklearn.model_selection import GridSearchCV
import pandas as pd
import matplotlib.pyplot as plt
from sklearn.ensemble import RandomForestRegressor
from sklearn.preprocessing import MinMaxScaler# 最小值最大值归一化
from sklearn.model_selection import train_test_split # 训练测试分割
from sklearn.neighbors import KNeighborsClassifier,KNeighborsRegressor

df = pd.read_csv(r'G:\Desktop\科委资格认证\新建文件夹\考试题\数据挖掘\数据集\creditcard.csv')
# 拆分为特征矩阵和目标向量
X = df.iloc[:,:-1]
Y = df.iloc[:,-1]
# 归一
s = MinMaxScaler()
s.fit(X)
X = s.transform(X)
# 分割训练集和测试集
train_x,test_x,train_y,test_y=train_test_split(X,Y,test_size=0.1)
# 显示出随机森林特征的重要性，并做条形图
rfr = RandomForestRegressor(min_samples_split=6, n_estimators=100)
#------------------------------
param_grid = [
    {'n_estimators': [3, 10, 30], 'max_features': [2, 4, 6, 8]},
    {'bootstrap': [False], 'n_estimators': [3, 10], 'max_features': [2, 3, 4]},
]

grid_search = GridSearchCV(rfr, param_grid, cv=5, scoring='neg_mean_squared_error')

grid_search.fit(train_x, train_y)


# @Time : 2020/7/21 9:54 
# @Author : XX
# @File : one.py 
# @Software: PyCharm

from sklearn.preprocessing import MinMaxScaler# 最小值最大值归一化
from sklearn.model_selection import train_test_split # 训练测试分割
from sklearn.neighbors import KNeighborsClassifier,KNeighborsRegressor
import pandas as pd
df = pd.read_csv(r'creditcard.csv')
# 拆分为特征矩阵和目标向量
X = df.iloc[:,:-1]
Y = df.iloc[:,-1]
# 归一
s = MinMaxScaler()
s.fit(X)
X = s.transform(X)
# 分割训练集和测试集
train_x,test_x,train_y,test_y=train_test_split(X,Y,test_size=0.1)
knn = KNeighborsClassifier(n_neighbors=5)
knn.fit(train_x,train_y)
print('KNN:',knn.score(test_x, test_y))


from selenium import webdriver
import pandas as pd
import time

class_name = input('请输入课程名：')
df = pd.read_excel('账号.xlsx',names=['username','password'],header=None)
print(df)
df['username']=df['username'].astype(str)
# print(df)
faillist = []
l = df.shape[0]
chrome_options = webdriver.ChromeOptions()
chrome_options.add_argument('--headless') # 隐藏浏览器
driver = webdriver.Chrome('chromedriver.exe', options=chrome_options)  # 浏览器对象
p_number = 0
faile_number = 0
def get_in_living_room(username,password):
    global p_number,faile_number
    try:
        url = 'http://www.aiquanti.com/loginPage'
        # chrome_options = webdriver.ChromeOptions()
        # chrome_options.add_argument('--headless') # 隐藏浏览器
        # driver = webdriver.Chrome('chromedriver.exe', options=chrome_options)  # 浏览器对象

        # driver.set_window_size(width=1920,height=1080)
        # driver.get('http://www.baidu.com') # 加载百度页面 和浏览器加载的形式一样 js，css
        driver.get(url)  # 加载完毕以后，页面的所有东西都在driver中
        # driver.save_screenshot('test.jpg')
        user_namebox = driver.find_element_by_xpath('//input[@id="login_account"]')
        user_passbox = driver.find_element_by_xpath('//input[@id="login_password"]')
        user_namebox.send_keys(username)
        user_passbox.send_keys(password)
        login_button = driver.find_element_by_xpath('//input[@id="login_submit"]')
        login_button.click()

        time.sleep(2)
        # print(driver.find_element_by_class_name('bdtn-hide'))
        # get_in_class = driver.find_elements_by_class_name('state now clear')
        get_in_class = driver.find_element_by_xpath('//span[text()="'+class_name+'"]')
        # print(get_in_class)
        webdriver.ActionChains(driver).move_to_element(get_in_class)
        # classB = driver.find_element_by_xpath('//span[@class="state now clear"]/button')
        get_in_class.click()
        get_in_class.click()
        get_in_class.click()
        get_in_class = driver.find_element_by_xpath('//button[text()="进入教室"]')
        get_in_class.click()
        time.sleep(2)
        print(username+'登陆成功')
        p_number += 1
        print('当前登录成功%d人'%p_number)

    except:
        print(username+'登录失败')
        faillist.append([username, password])
        faile_number+=1
        print('当前登录成功%d人' % p_number)




for i in range(l):
    username = df.iloc[i, :]['username']
    password = df.iloc[i, :]['password']
    get_in_living_room(username,password)


while True:
    print('如下账户登录失败：',faillist,'共'+str(len(faillist))+'人')
    if faillist:
        for i in faillist:
            get_in_living_room(i[0], i[1])
            faillist.remove(i)
    else:
        break

while True:
    time.sleep(1)


# @Time : 2020/7/21 10:54 
# @Author : XX
# @File : three.py 
# @Software: PyCharm
import jieba
import pandas as pd
from sklearn.feature_extraction.text import TfidfVectorizer
from sklearn.model_selection import train_test_split
from sklearn.tree import DecisionTreeClassifier


def get_text(text):
    return jieba.lcut(text)

df = pd.read_csv()
X = df.iloc[:,1:]
Y = df.iloc[:,0]
# tokenizer分词器,停用词
with open(r'') as r:
    stop_words = r.readlines()
tf = TfidfVectorizer(tokenizer=get_text,stop_words=stop_words)
X = tf.fit_transform(df['content'])
train_X,test_X,train_Y,test_Y = train_test_split(X,Y)
tree = DecisionTreeClassifier()
tree.fit(train_X,train_Y)
print(tree.score(test_X,test_Y))


# @Time : 2020/7/21 10:58 
# @Author : XX
# @File : five.py 
# @Software: PyCharm

import logging
import gensim
from gensim.models import word2vec

word2vec.LineSentence("")
model = gensim.models.Word2Vec(sentences, size=200, sg=1, iter=8)
model.wv.save_word2vec_format()
wordVec = gensim.models.KeyedVectors.load_word2vec_format()


# @Time : 2020/7/21 10:55 
# @Author : XX
# @File : four.py 
# @Software: PyCharm
from keras.layers import Conv2D, MaxPool2D, Flatten, Dense
from keras.models import Sequential


model = Sequential()
model.add(Conv2D())
model.add(MaxPool2D())
model.add(Conv2D())
model.add(Conv2D())
model.add(Conv2D())
model.add(Conv2D())
model.add(MaxPool2D())
model.add(Flatten())
model.add(Dense())
model.add(Dense())
model.add(Dense())


# @Time : 2020/7/21 10:25 
# @Author : XX
# @File : setup.py.py 
# @Software: PyCharm

# coding=utf-8

from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()


setup(
    name='result_xx',  # '库的名称,一般写成文件夹的名字就可以了，也有的人不写成文件夹的名字，那么pip install和具体的import使用时候就不一样了，用起来会十分蛋疼，有一些包就是这样的。比如一个包，安装时候是pip install  xxx,但当你要使用时候要import yyy
    version="1.0.2",                  # 版本，每次发版本都不能重复，每次发版必须改这个地方
    description=(
        'nothing'   # 一个简介，别人搜索包时候，这个概要信息会显示在在搜索列表中
    ),
    long_description=open('README.md', 'r').read(),    # 这是详细的，一般是交别人怎么用，很多包没写，那么在官网就造成没有使用介绍了
    long_description_content_type="text/markdown",
    author='xx',       # 作者
    author_email='yydssb@126.com',
    maintainer='xx',     # 主要的工作人员
    maintainer_email='yydssb@126.com',
    license='BSD License',
    # packages=['douban'], # 发布的包名
    packages=find_packages(),
    platforms=["all"],
    # url='https://www.baidu.com',   # 这个是连接，一般写github就可以了，会从pypi跳转到这里去
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries'
    ],
    install_requires=[              # 这里是依赖列表，表示运行这个包的运行某些功能还需要你安装其他的包
        'gensim',
    ]
)


# @Time : 2020/7/21 10:53 
# @Author : XX
# @File : two.py 
# @Software: PyCharm


import os
import pandas as pd
import numpy as np
from sklearn.preprocessing import StandardScaler
from keras.layers import Conv2D,MaxPool2D,Dense,Flatten
from keras.utils import np_utils
from keras.models import Sequential
from sklearn.model_selection import train_test_split
model = Sequential()
# 1. 两个卷积层，一个池化层
#     卷积层：64个卷积核
model.add(Conv2D(filters=64,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=64,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 2. 两个卷积一个池化
#     卷积层：128个卷积核
model.add(Conv2D(filters=128,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=128,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 3. 三个卷积一个池化
#     卷积：256个卷积核
model.add(Conv2D(filters=256,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=256,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=256,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 4. 三个卷积一个池化
#     卷积：512个卷积核
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 5. 三个卷积一个池化
#     卷积：512个卷积核
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(Conv2D(filters=512,kernel_size=(3,3),padding='same'))
model.add(MaxPool2D(pool_size=(2,2)))
# 6. 全连接层：
#     1. 神经元：4096个，Relu
model.add(Flatten())
model.add(Dense(units=4096,activation='relu'))
#     2. 神经元：4096个，Relu
model.add(Dense(units=4096,activation='relu'))
#     3. 神经元：1000个，SoftMax
model.add(Dense(units=5,activation='softmax'))
model.compile(optimizer='adam',loss='categorical_crossentropy',metrics=['accuracy'])
# model.fit(datas,Y,epochs=200)
#
# Result = model.predict(X)
# Return HTTPResponse('result.html',{'result':result})